@@ -81,7 +81,7 @@ char *myreadline(const char *prompt) {
 			}
 		}
 
-		if (isatty(fileno(settings.scriptfp))) {
+		if (isatty(fileno(settings.scriptfp)) && !settings.oldstyle) {
 			free(buf);               // LCOV_EXCL_LINE
 			return readline(prompt); // LCOV_EXCL_LINE
 		} else {
@@ -152,8 +152,8 @@ static void checkhints(void) {
 					game.hints[hint].lc = 0;
 					return;
 				case 4: /* dark */
-					if (!PROP_IS_NOTFOUND(EMERALD) &&
-					    PROP_IS_NOTFOUND(PYRAMID)) {
+					if (!OBJECT_IS_NOTFOUND(EMERALD) &&
+					    OBJECT_IS_NOTFOUND(PYRAMID)) {
 						break;
 					}
 					game.hints[hint].lc = 0;
@@ -188,7 +188,8 @@ static void checkhints(void) {
 					return;
 				case 9: /* jade */
 					if (game.tally == 1 &&
-					    PROP_IS_STASHED_OR_UNSEEN(JADE)) {
+					    (OBJECT_IS_STASHED(JADE) ||
+					     OBJECT_IS_NOTFOUND(JADE))) {
 						break;
 					}
 					game.hints[hint].lc = 0;
@@ -231,8 +232,8 @@ static bool spotted_by_pirate(int i) {
 	 *  tally=1 for an unseen chest, let the pirate be spotted.  Note
 	 *  that game.objexts,place[CHEST] = LOC_NOWHERE might mean that he's
 	 * thrown it to the troll, but in that case he's seen the chest
-	 *  PROP_IS_FOUND(CHEST) == true. */
-	if (game.loc == game.chloc || !PROP_IS_NOTFOUND(CHEST)) {
+	 *  OBJECT_IS_FOUND(CHEST) == true. */
+	if (game.loc == game.chloc || !OBJECT_IS_NOTFOUND(CHEST)) {
 		return true;
 	}
 	int snarfed = 0;
@@ -533,7 +534,7 @@ static void describe_location(void) {
 		msg = locations[game.loc].description.big;
 	}
 
-	if (!FORCED(game.loc) && DARK(game.loc)) {
+	if (!FORCED(game.loc) && IS_DARK_HERE()) {
 		msg = arbitrary_messages[PITCH_DARK];
 	}
 
@@ -639,7 +640,7 @@ static void playermove(int motion) {
 	} else if (motion == CAVE) {
 		/*  Cave.  Different messages depending on whether above ground.
 		 */
-		rspeak((OUTSID(game.loc) && game.loc != LOC_GRATE)
+		rspeak((OUTSIDE(game.loc) && game.loc != LOC_GRATE)
 		           ? FOLLOW_STREAM
 		           : NEED_DETAIL);
 		return;
@@ -1046,7 +1047,7 @@ static void listobjects(void) {
 	 *  Similarly for chain; game.prop is initially CHAINING_BEAR (locked to
 	 *  bear).  These hacks are because game.prop=0 is needed to
 	 *  get full score. */
-	if (!DARK(game.loc)) {
+	if (!IS_DARK_HERE()) {
 		++game.locs[game.loc].abbrev;
 		for (int i = game.locs[game.loc].atloc; i != 0;
 		     i = game.link[i]) {
@@ -1061,11 +1062,11 @@ static void listobjects(void) {
 			 * running this code only on objects with the treasure
 			 * property set. Nope.  There is mystery here.
 			 */
-			if (PROP_IS_STASHED_OR_UNSEEN(obj)) {
+			if (OBJECT_IS_STASHED(i) || OBJECT_IS_NOTFOUND(obj)) {
 				if (game.closed) {
 					continue;
 				}
-				PROP_SET_FOUND(obj);
+				OBJECT_SET_FOUND(obj);
 				if (obj == RUG) {
 					game.objects[RUG].prop = RUG_DRAGON;
 				}
@@ -1192,7 +1193,7 @@ static bool preprocess_command(command_t *command) {
 static bool do_move(void) {
 	/* Actually execute the move to the new location and dwarf movement */
 	/*  Can't leave cave once it's closing (except by main office). */
-	if (OUTSID(game.newloc) && game.newloc != 0 && game.closng) {
+	if (OUTSIDE(game.newloc) && game.newloc != 0 && game.closng) {
 		rspeak(EXIT_CLOSED);
 		game.newloc = game.loc;
 		if (!game.panic) {
@@ -1228,7 +1229,7 @@ static bool do_move(void) {
 
 	/* The easiest way to get killed is to fall into a pit in
 	 * pitch darkness. */
-	if (!FORCED(game.loc) && DARK(game.loc) && game.wzdark &&
+	if (!FORCED(game.loc) && IS_DARK_HERE() && game.wzdark &&
 	    PCT(PIT_KILL_PROB)) {
 		rspeak(PIT_FALL);
 		game.oldlc2 = game.loc;
@@ -1266,25 +1267,28 @@ static bool do_command(void) {
 				 * way objects won't be described until they've
 				 * been picked up and put down separate from
 				 * their respective piles. */
-				if ((PROP_IS_NOTFOUND(OYSTER) ||
-				     PROP_IS_STASHED(OYSTER)) &&
+				if ((OBJECT_IS_NOTFOUND(OYSTER) ||
+				     OBJECT_IS_STASHED(OYSTER)) &&
 				    TOTING(OYSTER)) {
 					pspeak(OYSTER, look, true, 1);
 				}
 				for (size_t i = 1; i <= NOBJECTS; i++) {
-					if (TOTING(i) && (PROP_IS_NOTFOUND(i) ||
-					                  PROP_IS_STASHED(i))) {
-						game.objects[i].prop =
-						    PROP_STASHED(i);
+					if (TOTING(i) &&
+					    (OBJECT_IS_NOTFOUND(i) ||
+					     OBJECT_IS_STASHED(i))) {
+						OBJECT_STASHIFY(
+						    i, game.objects[i].prop);
 					}
 				}
 			}
 
-			/* Check to see if the room is dark. If the knife is
-			 * here, and it's dark, the knife permanently disappears
-			 */
-			game.wzdark = DARK(game.loc);
-			if (game.knfloc != LOC_NOWHERE &&
+			/* Check to see if the room is dark. */
+			game.wzdark = IS_DARK_HERE();
+
+			/* If the knife is not here it permanently disappears.
+			 * Possibly this should fire if the knife is here but
+			 * the room is dark? */
+			if (game.knfloc > LOC_NOWHERE &&
 			    game.knfloc != game.loc) {
 				game.knfloc = LOC_NOWHERE;
 			}
