@@ -12,6 +12,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <strings.h>
 #include <sys/time.h>
 #include <unistd.h>
 
@@ -495,8 +496,8 @@ static void tokenize(char *raw, command_t *cmd) {
 	memset(&cmd->word[1].raw, '\0', sizeof(cmd->word[1].raw));
 
 	/* Bound prefix on the %s would be needed to prevent buffer
-	 * overflow.  but we shortstop this more simply by making each
-	 * raw-input buffer as int as the entire input buffer. */
+	 * overflow. We shortstop this more simply by making each
+	 * raw-input buffer as long as the entire input buffer. */
 	sscanf(raw, "%s%s", cmd->word[0].raw, cmd->word[1].raw);
 
 	/* (ESR) In oldstyle mode, simulate the uppercasing and truncating
@@ -512,10 +513,14 @@ static void tokenize(char *raw, command_t *cmd) {
 	 * in their tools. On the other, not simulating this misbehavior
 	 * goes against the goal of making oldstyle as accurate as
 	 * possible an emulation of the original UI.
+	 *
+	 * The definition of TRUNCLEN is dubious. It accurately reflects the
+	 * FORTRAN, but it's possible that was a bug and the proper definition
+	 * is (TOKLEN).
 	 */
+#define TRUNCLEN (TOKLEN + TOKLEN)
 	if (settings.oldstyle) {
-		cmd->word[0].raw[TOKLEN + TOKLEN] =
-		    cmd->word[1].raw[TOKLEN + TOKLEN] = '\0';
+		cmd->word[0].raw[TRUNCLEN] = cmd->word[1].raw[TRUNCLEN] = '\0';
 		for (size_t i = 0; i < strlen(cmd->word[0].raw); i++) {
 			cmd->word[0].raw[i] = toupper(cmd->word[0].raw[i]);
 		}
@@ -617,14 +622,12 @@ void move(obj_t object, loc_t where) {
 }
 
 void put(obj_t object, loc_t where, int pval) {
-	/*  put() is the same as move(), except it returns a value used to set
-	 * up the negated game.prop values for the repository objects. */
+	/* put() is the same as move(), except the object is stashed and
+	 * can no longer be picked up. */
 	move(object, where);
-	/* (ESR) Read this in combination with the macro defintions in advebt.h.
-	 */
-	game.objects[object].prop = PROP_STASHIFY(pval);
-#ifdef PROP_SET_SEEN
-	PROP_SET_SEEN(object);
+	OBJECT_STASHIFY(object, pval);
+#ifdef OBJECT_SET_SEEN
+	OBJECT_SET_SEEN(object);
 #endif
 }
 
